.. _spider_addendum.org:

addendum.org
------------
Newest articles from `Addendum <https://www.addendum.org>`_.

Configuration
~~~~~~~~~~~~~
Add ``addendum.org`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     addendum.org

